==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_12_Board_Mini_STM32_v30.sh <==
#!/bin/bash

#
#  Install script for protoboard Mini-STM32 v3.0 with 2,8" Color Touch Display
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="100_board_mini_stm32_v30"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  Dir=`pwd`
  dir ../../Documentation/Boards
  cd ../../Documentation/Boards
  
  dir Mini-STM32
  cd Mini-STM32
  DocDir=`pwd`
  if [ ! -e $Dir/OK.Docs ]; then #{
    Get_Fails=""
    getFile http://www.cutedigi.com/pub/ARMCORTEX/ STM32-FD-HX.pdf Schematics.pdf
    getFile http://www.rcos.eu/targets/stm32tft-backend/Datasheets/ Mini%20STM32%20Entwicklungsboard%20Anleitung.pdf Mini-STM32_Entwicklungsboard_Anleitung.pdf
    if [ "$Get_Fails" == "" ]; then
      touch $Dir/OK.Docs
    else
      echo "$0 - ERROR: missing files: $Get_Fails"
    fi
  fi #}
  cd "$Dir"
  if [ ! -e OK.Install ]; then #{
    getFile "http://hlb-labor.de/cortexm3/ProtoBoards/" "FreeRTOS_on_MINI-STM32.tar.bz2"
    getFile "http://hlb-labor.de/cortexm3/ProtoBoards/" "MINI-STM32.tar.bz2"
    untgj FreeRTOS_on_MINI-STM32 FreeRTOS_on_MINI-STM32.tar.bz2
    untgj MINI-STM32 MINI-STM32.tar.bz2
  
    if [ -d FreeRTOS_on_MINI-STM32/ ]; then #{
      chmod -R +rw FreeRTOS_on_MINI-STM32
      if [ -d MINI-STM32/ ]; then
        chmod -R +rw MINI-STM32
        cd MINI-STM32/
        for File in "MINI-STM32 Schematic" "TFT Driver Information" "TouchScreen Information" "usermanual"; do
          echo "copying docmentation '$File'"
          if [ -d "$File" ]; then
            cp -R "$File" $DocDir/
            #echo "cp -Rv \"$File\" $DocDir/"
          fi
        done
        cd ..
        touch OK.Install
      fi
    fi #}
  fi #}
  if [ -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    addLine ../scripts/createLinks.sh "rm 2>/dev/null $INSTALLPATH; ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/FreeRTOS_on_MINI-STM32/Source/Mini_STM32/  $INSTALLPATH"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}"
    cat <<END_OF_MAKEFILE >>$File 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name
COMPILE_OPTS += -DBOARD=$Name
BOARD = $Name

# define microcontroller used on board
STM32F10X_MD   = 1
COMPILE_OPTS += -DUC_DEVICE=STM32F103RBT6
COMPILE_OPTS += -DUC_PACKAGE_PINS=64

INCLUDE_DIRS += -I additionals/$Name/

COMPILE_OPTS += -DRAM_SIZE_K=20
COMPILE_OPTS += -DRAM_START=0x20000000
COMPILE_OPTS += -DFLASH_SIZE_K=128
COMPILE_OPTS += -DFLASH_START=0x08000000

vpath %.c additionals/$Name/

# set some well known port defines
  COMPILE_OPTS += -DPB_LED1=GPIOA,2       # status LED 1
  COMPILE_OPTS += -DPB_LED2=GPIOA,3       # status LED 2
  COMPILE_OPTS += -DPB_SWITCH1=GPIOA,0    # press button switch 1
  COMPILE_OPTS += -DPB_SWITCH2=GPIOA,1    # press button switch 2
  COMPILE_OPTS += -DPB_VR1=GPIOB,0        # potentiometer 3V3 -|R33|- GND
  COMPILE_OPTS += -DTTC_USART1_TX=GPIOA,10  # Serial2MiniUSB converter PL2303HX TX-Pin
  COMPILE_OPTS += -DTTC_USART1_RX=GPIOA,9   # Serial2MiniUSB converter PL2303HX RX-Pin
  COMPILE_OPTS += -DTTC_USART1=USART1       # Serial2MiniUSB converter PL2303HX connected USART
  
END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{
    createActivateScriptHead $File $0 "Protoboard Mini-STM32 with 2,8\" Color Touch LCD and STM32F103RBT6"
  cat <<END_OF_ACTIVATE >>$File #{

  rm 2>/dev/null \$Dir_ExtensionsActive/makefile.100_board_*
  
  # create links into extensions.active/
  createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
  
  activate.200_cpu_stm32f10x.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    echo "Installed successfully: $INSTALLPATH"
  else
    echo "ERROR occured during install: $INSTALLPATH"
    exit 10
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.39.tar.bz: ToolChain_STM32_1.0.39/ToolChain/install_12_Board_Mini_STM32_v30.sh <==
#!/bin/bash

#
#  Install script for protoboard Mini-STM32 v3.0 with 2,8" Color Touch Display
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="100_board_mini_stm32_v30"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  Dir=`pwd`
  dir ../../Documentation/Boards
  cd ../../Documentation/Boards
  
  dir Mini-STM32
  cd Mini-STM32
  DocDir=`pwd`
  if [ ! -e $Dir/OK.Docs ]; then #{
    Get_Fails=""
    getFile http://www.cutedigi.com/pub/ARMCORTEX/ STM32-FD-HX.pdf Schematics.pdf
    getFile http://www.rcos.eu/targets/stm32tft-backend/Datasheets/ Mini%20STM32%20Entwicklungsboard%20Anleitung.pdf Mini-STM32_Entwicklungsboard_Anleitung.pdf
    if [ "$Get_Fails" == "" ]; then
      touch $Dir/OK.Docs
    else
      echo "$0 - ERROR: missing files: $Get_Fails"
    fi
  fi #}
  cd "$Dir"
  if [ ! -e OK.Install ]; then #{
    getFile "http://hlb-labor.de/cortexm3/ProtoBoards/" "FreeRTOS_on_MINI-STM32.tar.bz2"
    getFile "http://hlb-labor.de/cortexm3/ProtoBoards/" "MINI-STM32.tar.bz2"
    untgj FreeRTOS_on_MINI-STM32 FreeRTOS_on_MINI-STM32.tar.bz2
    untgj MINI-STM32 MINI-STM32.tar.bz2
  
    if [ -d FreeRTOS_on_MINI-STM32/ ]; then #{
      chmod -R +rw FreeRTOS_on_MINI-STM32
      if [ -d MINI-STM32/ ]; then
        chmod -R +rw MINI-STM32
        cd MINI-STM32/
        for File in "MINI-STM32 Schematic" "TFT Driver Information" "TouchScreen Information" "usermanual"; do
          echo "copying docmentation '$File'"
          if [ -d "$File" ]; then
            cp -R "$File" $DocDir/
            #echo "cp -Rv \"$File\" $DocDir/"
          fi
        done
        cd ..
        touch OK.Install
      fi
    fi #}
  fi #}
  if [ -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    addLine ../scripts/createLinks.sh "rm 2>/dev/null $INSTALLPATH; ln -sv \$Source/ToolChain_STM32/ToolChain/$INSTALLPATH/FreeRTOS_on_MINI-STM32/Source/Mini_STM32/  $INSTALLPATH"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}"
    cat <<END_OF_MAKEFILE >>$File 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1
COMPILE_OPTS += -DBOARD=$Name
BOARD=$Name

# define microcontroller used on board
STM32F10X_MD  =1
COMPILE_OPTS += -DUC_DEVICE=STM32F103RBT6
COMPILE_OPTS += -DUC_PACKAGE_PINS=64

INCLUDE_DIRS += -I additionals/$Name/

COMPILE_OPTS += -DRAM_SIZE_K=20
COMPILE_OPTS += -DRAM_START=0x20000000
COMPILE_OPTS += -DFLASH_SIZE_K=128
COMPILE_OPTS += -DFLASH_START=0x08000000

vpath %.c additionals/$Name/

# set some well known port defines
  COMPILE_OPTS += -DPB_LED1=GPIOA,2       # status LED 1
  COMPILE_OPTS += -DPB_LED2=GPIOA,3       # status LED 2
  COMPILE_OPTS += -DPB_SWITCH1=GPIOA,0    # press button switch 1
  COMPILE_OPTS += -DPB_SWITCH2=GPIOA,1    # press button switch 2
  COMPILE_OPTS += -DPB_VR1=GPIOB,0        # potentiometer 3V3 -|R33|- GND
  COMPILE_OPTS += -DTTC_USART1_TX=GPIOA,10  # Serial2MiniUSB converter PL2303HX TX-Pin
  COMPILE_OPTS += -DTTC_USART1_RX=GPIOA,9   # Serial2MiniUSB converter PL2303HX RX-Pin
  COMPILE_OPTS += -DTTC_USART1=USART1       # Serial2MiniUSB converter PL2303HX connected USART
  
END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{
    createActivateScriptHead $File $0 "Protoboard Mini-STM32 with 2,8\" Color Touch LCD and STM32F103RBT6"
  cat <<END_OF_ACTIVATE >>$File #{

  rm 2>/dev/null \$Dir_ExtensionsActive/makefile.100_board_*
  
  # create links into extensions.active/
  createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
  
  activate.200_cpu_stm32f10x.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    echo "Installed successfully: $INSTALLPATH"
  else
    echo "ERROR occured during install: $INSTALLPATH"
    exit 10
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
